@@ -78,7 +78,7 @@ int main(int argc, char *argv[])
   aboutData.addAuthor(i18n("Johann Ollivier Lapeyre"),i18n("Graphics"), QStringLiteral("johann.ollivierlapeyre@gmail.com"));
   aboutData.addAuthor(i18n("Eugene Trounev"),i18n("Graphics"), QStringLiteral("eugene.trounev@gmail.com"));
   aboutData.addAuthor(i18n("Benjamin Meyer"), i18n("Code Improvements"));
-  aboutData.setHomepage(QStringLiteral("http://games.kde.org/kfourinline"));
+  aboutData.setHomepage(QStringLiteral("https://kde.org/applications/games/org.kde.kfourinline"));
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
     KCrash::initialize();
